pis
===

.. image:: https://img.shields.io/pypi/v/pis.svg
    :target: https://pypi.python.org/pypi/pis
    :alt: Latest PyPI version

.. image:: -.png
   :target: -
   :alt: Latest Travis CI build status

todo

Usage
-----

Installation
------------

Requirements
^^^^^^^^^^^^

Compatibility
-------------

Licence
-------

Authors
-------

`pis` was written by `xliiv <tymoteusz.jankowski@gmail.com>`_.
